<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:rx="http://www.renderx.com/XSL/Extensions"
    version="1.0">
    <xsl:include href="scale-all-to-fit.xsl"/>
    <xsl:param name="xepdoc" select="document('image.xep')"/>
    <xsl:variable name="page-width">400</xsl:variable>
    <xsl:variable name="page-height">400</xsl:variable>
    <xsl:variable name="margin-left">20</xsl:variable>
    <xsl:variable name="margin-right">20</xsl:variable>
    <xsl:variable name="margin-bottom">40</xsl:variable>
    <xsl:variable name="margin-top">40</xsl:variable>
    <xsl:variable name="caption-height">16</xsl:variable>
    <xsl:template match="images">
    <fo:root>
        <fo:layout-master-set>
            <fo:simple-page-master master-name="page">
                <xsl:attribute name="page-width">
                    <xsl:value-of select="$page-width"/>pt
                </xsl:attribute>
                <xsl:attribute name="page-height">
                    <xsl:value-of select="$page-height"/>pt
                </xsl:attribute>
                <xsl:attribute name="margin-top">
                    <xsl:value-of select="$margin-top"/>pt
                </xsl:attribute>
                <xsl:attribute name="margin-bottom">
                    <xsl:value-of select="$margin-bottom"/>pt
                </xsl:attribute>
                <xsl:attribute name="margin-left">
                    <xsl:value-of select="$margin-left"/>pt
                </xsl:attribute>
                <xsl:attribute name="margin-right">
                    <xsl:value-of select="$margin-right"/>pt
                </xsl:attribute>
                <fo:region-body margin-top="0pt"/>
                <fo:region-before extent="0pt"/>
                <fo:region-after extent="0pt"/>
            </fo:simple-page-master>
        </fo:layout-master-set>
        <fo:page-sequence master-reference="page">
            <fo:flow flow-name="xsl-region-body">
                    <xsl:apply-templates/>
            </fo:flow>
        </fo:page-sequence>
    </fo:root>
    </xsl:template>
    <xsl:template match="image[@scale-all-to-fit = 'true']">
        <fo:block line-height="0pt" text-align="center" background-color="silver">
        <xsl:call-template name="scale-image-to-fit">
            <xsl:with-param name="xepdoc" select="$xepdoc"/>
            <xsl:with-param name="fit-height">
                <xsl:value-of select="$page-height - $margin-top - $margin-bottom - $caption-height"/>
            </xsl:with-param>
            <xsl:with-param name="fit-width">
                <xsl:value-of select="$page-width - $margin-left - $margin-right"/>
            </xsl:with-param>
            <xsl:with-param name="image-name" select="@src"/>
        </xsl:call-template>
        </fo:block>
        <fo:block space-before="3pt" text-align="center" keep-with-previous.within-column="always" font-size="10pt" font-weight="bold" font-style="italic">
            <xsl:value-of select="@caption"/>
        </fo:block>
    </xsl:template>
    <xsl:template match="image">
        <fo:block line-height="0pt" text-align="center" background-color="yellow">
            <fo:external-graphic>
                <xsl:attribute name="src">
                    <xsl:text>url('</xsl:text>
                    <xsl:value-of select="@src"/>
                    <xsl:text>')</xsl:text>
                </xsl:attribute>
            </fo:external-graphic>
        </fo:block>
        <fo:block space-before="3pt" text-align="center" keep-with-previous.within-column="always" font-size="10pt" font-weight="bold" font-style="italic">
            <xsl:value-of select="@caption"/>
        </fo:block>
    </xsl:template>
    <xsl:template match="p">
        <fo:block space-before="6pt" space-after="6pt">
        <xsl:apply-templates/>
        </fo:block>
    </xsl:template>
</xsl:stylesheet>
